@@ -9,8 +9,8 @@ pub const COMMANDS: &'static [(&'static str, &'static str)] = &[
     ("(con)fig save", "[<serial>] - saves device config for specific/selected device"),
     ("(con)fig import", "[<serial>] <path> - imports device config from a file for specific/selected device"),
     ("(con)fig export", "[<serial>] <path> - exports device config into a file for specific/selected device"),
-    ("(br)ightness", "[<serial>] <0-255> - sets brightness for device, different for each device, but usually 0-100"),
-    ("(ba)ck", "[<serial>] - navigates back, even if there's no button for that"),
+    ("(br)ightness", "[<serial>] <0-100> - sets brightness for device"),
+    ("(ba)ck", "[<serial>] [drop] - navigates back, even if there's no button for that, if drop is included, goes to root screen"),
     ("(p)ress", "[<serial>] <key index> - simulates a press on a button"),
     ("(m)odule (l)ist", "- lists all loaded modules"),
     ("(m)odule (i)nfo", "<name> - prints information about module"),
@@ -24,6 +24,7 @@ pub const COMMANDS: &'static [(&'static str, &'static str)] = &[
     ("(i)mage (l)ist", "[<serial>] [preview size] - lists all images used by a device, optionally sizes images according to provided size"),
     ("(i)mage (a)dd", "[<serial>] <file path> - adds image to device config"),
     ("(i)mage (r)emove", "[<serial>] <identifier> - removes image from device config"),
+    ("stack", "[<serial>] - prints current stack"),
     ("(b)utton (l)ist", "[<serial>] - lists all buttons defined on current screen"),
     ("(b)utton (i)nfo", "[<serial>] <key index> - provides more detailed information about a button"),
     ("(b)utton (n)ew", "[<serial>] <key index> - creates an empty button on current screen"),
