@@ -1,8 +1,9 @@
 use std::str::Split;
-use streamduck_client::daemon::daemon_data::{GetButtonResult, GetComponentValuesResult, GetCurrentScreenResult, GetStackResult};
+use streamduck_client::daemon::daemon_data::buttons::{GetButtonResult, GetComponentValuesResult};
+use streamduck_client::daemon::daemon_data::panels::{GetCurrentScreenResult, GetStackNamesResult};
 use streamduck_client::util::module_component_map_to_component_map;
 use streamduck_core::core::button::Button;
-use streamduck_core::modules::components::{ComponentDefinition, UIFieldValue, UIValue};
+use streamduck_core::modules::components::{ComponentDefinition, UIFieldValue, UIPathValue};
 use crate::helps::COMMANDS;
 use crate::prompt::ClientRef;
 use crate::prompt::utils::{print_table, print_table_with_strings};
@@ -117,15 +118,15 @@ pub fn list_buttons(client: ClientRef, current_sn: &str) {
 
 pub fn show_stack(client: ClientRef, current_sn: &str) {
     if !current_sn.is_empty() {
-        let screen = client.get_stack(current_sn).expect("Failed to get stack");
+        let screen = client.get_stack_names(current_sn).expect("Failed to get stack");
 
         match screen {
-            GetStackResult::DeviceNotFound => println!("stack: Device not found"),
-            GetStackResult::Stack(stack) => {
+            GetStackNamesResult::DeviceNotFound => println!("stack: Device not found"),
+            GetStackNamesResult::Stack(stack) => {
                 println!("Current stack:");
 
                 for panel in stack {
-                    println!("- '{}'", panel.display_name);
+                    println!("- '{}'", panel);
                 }
             }
         }
@@ -154,7 +155,7 @@ pub fn button_info(client: ClientRef, current_sn: &str, mut args: Split<&str>) {
 
                                 let values = client.get_component_values(current_sn, key, &name).expect("Failed to get component values");
 
-                                fn print_values(values: &Vec<UIValue>, tabulation: usize) {
+                                fn print_values(values: &Vec<UIPathValue>, tabulation: usize) {
                                     for value in values {
                                         if let UIFieldValue::Array(arr) = &value.value {
                                             println!("{s: <w$}{}: {{", value.name, w = tabulation, s = "");
